@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: atoms.c,v 1.10 1999/11/28 17:56:37 nisse Exp $ */
+ * $Id: atoms.c,v 1.11 2000/04/23 17:48:44 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -48,7 +48,8 @@ UINT32 get_atom_length(int atom)
 const UINT8 *get_atom_name(int atom)
 { return atom_table[atom].name; }
   
-UINT32 lookup_atom(UINT32 length, UINT8 *name)
+UINT32
+lookup_atom(UINT32 length, const UINT8 *name)
 {
   const struct atom_assoc *pair = gperf_atom(name, length);
 
