@@ -2,7 +2,7 @@
  *
  * Client specific key exchange handling
  *
- * $Id: client_keyexchange.h,v 1.14 1999/12/07 22:35:07 nisse Exp $ */
+ * $Id: client_keyexchange.h,v 1.16 2000/05/27 23:59:22 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -27,13 +27,12 @@
 #define LSH_CLIENT_KEYEXCHANGE_H_INCLUDED
 
 #include "keyexchange.h"
-/* #include "lookup_verifier.h" */
 #include "publickey_crypto.h"
 
 struct keyexchange_algorithm *
-make_dh_client(struct diffie_hellman_method *dh);
-     /* struct alist *verifiers); */
+make_dh_client(struct dh_method *dh);
 
-struct install_keys *make_client_install_keys(struct object_list *algorithms);
+struct keyexchange_algorithm *
+make_srp_client(struct dh_method *dh, struct lsh_string *name);
 
 #endif /* LSH_CLIENT_KEYEXCHANGE_H_INCLUDED */
