@@ -1,6 +1,6 @@
 /* connection_commands.h
  *
- * $Id: connection_commands.h,v 1.8 2000/02/07 20:52:53 nisse Exp $
+ * $Id: connection_commands.h,v 1.10 2000/06/01 17:07:25 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -38,8 +38,10 @@
    (class
      (name handshake_info)
      (vars
+       ; Initial value for the connection flags. Usually
        ; CONNECTION_SERVER or CONNECTION_CLIENT
-       (mode . int)
+       (flags . UINT32)
+       
        (block_size simple UINT32)
        (id_comment simple "const char *")
        (debug_comment simple "const char *")
@@ -54,7 +56,7 @@
 */
 
 struct handshake_info *
-make_handshake_info(int mode,
+make_handshake_info(UINT32 flags,
 		    const char *id_comment,
 		    const char *debug_comment,
 		    UINT32 block_size,
@@ -71,4 +73,14 @@ struct close_callback *make_connection_close_handler(struct ssh_connection *c);
 struct command_simple connection_remember;
 #define CONNECTION_REMEMBER (&connection_remember.super.super)
 
+struct command *
+make_connection_if_srp(struct command *then_f,
+		       struct command *else_f);
+
+extern struct collect_info_1 connection_if_srp_command;
+#define CONNECTION_IF_SRP (&connection_if_srp_command.super.super.super)
+
+extern struct command connection_require_userauth;
+#define CONNECTION_REQUIRE_USERAUTH (&connection_require_userauth.super)
+
 #endif /* LSH_CONNECTION_COMMANDS_H_INCLUDED */
