@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: debug.c,v 1.32 2000/02/06 22:14:39 nisse Exp $ */
+ * $Id: debug.c,v 1.33 2000/04/23 17:48:48 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -114,7 +114,7 @@ do_rec_debug(struct packet_handler *self UNUSED,
   unsigned msg_number;
   unsigned always_display;
   UINT32 length;
-  UINT8 *msg;
+  const UINT8 *msg;
   int language;
   
   simple_buffer_init(&buffer, packet->length, packet->data);
