@@ -2,7 +2,7 @@
  *
  * Packet processor dumping packets to a file.
  *
- * $Id: debug.h,v 1.13 2000/02/06 22:14:40 nisse Exp $ */
+ * $Id: debug.h,v 1.14 2000/06/27 11:36:40 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -40,4 +40,4 @@ void send_verbose(struct abstract_write *write, const char *msg, int always_disp
 
 struct packet_handler *make_rec_debug_handler(void);
 
-#endif */ LSH_DEBUG_H_INCLUDED */
+#endif /* LSH_DEBUG_H_INCLUDED */
