@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: format.c,v 1.36 2000/04/23 17:48:49 nisse Exp $ */
+ * $Id: format.c,v 1.37 2000/05/06 11:17:32 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -655,32 +655,10 @@ lsh_string_eq_l(const struct lsh_string *a,
 	   && !memcmp(a->data, b, length));
 }
 
-int lsh_string_prefixp(const struct lsh_string *prefix,
-		       const struct lsh_string *s)
+int
+lsh_string_prefixp(const struct lsh_string *prefix,
+		   const struct lsh_string *s)
 {
   return ( (prefix->length <= s->length)
 	   && !memcmp(prefix->data, s->data, prefix->length));
 }
-
-#if 0
-/* FIXME: These functions don't really belong here */
-int lsh_string_cmp(const struct lsh_string *a, const struct lsh_string *b)
-{
-  if (a->length < b->length)
-    return -1;
-  else if (a->length > b->length)
-    return 1;
-  else
-    return memcmp(a->data, b->data, a->length);
-}
-
-int lsh_string_cmp_l(const struct lsh_string *a, UINT32 length, const UINT8 *b)
-{
-  if (a->length < length)
-    return -1;
-  else if (a->length > length)
-    return 1;
-  else
-    return memcmp(a->data, b, length);
-}
-#endif
