@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: keyexchange.h,v 1.44 2000/05/28 00:15:40 nisse Exp $ */
+ * $Id: keyexchange.h,v 1.46 2000/06/01 13:18:06 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -111,32 +111,6 @@
 */
 
 #define MAKE_KEXINIT(s) ((s)->make((s)))
-
-/* FIXME: We don't need this class. */
-/* Installs keys for use. */
-/* GABA:
-   (class
-     (name install_keys)
-     (vars
-       (install method int
-		"struct ssh_connection *connection"
-		"struct hash_instance *secret")))
-*/
-
-#define INSTALL_KEYS(i, c, s) ((i)->install((i), (c), (s)))
-
-/* GABA:
-   (class
-     (name newkeys_info)
-     (vars
-       (encryption_client_to_server  object crypto_algorithm)
-       (encryption_server_to_client  object crypto_algorithm)
-       (mac_client_to_server         object mac_algorithm)
-       (mac_server_to_client         object mac_algorithm)
-       ;; (compression_client_to_server object compression_algorithm)
-       ;; (compression_server_to_client object compression_algorithm)
-       ))
-*/
      
 struct lsh_string *format_kex(struct kexinit *kex);
 void disconnect_kex_failed(struct ssh_connection *connection, const char *msg);
@@ -166,12 +140,10 @@ struct make_kexinit *make_simple_kexinit(struct randomness *r,
 
 struct make_kexinit *make_test_kexinit(struct randomness *r);
 
-void initiate_keyexchange(struct ssh_connection *connection,
-			 int type);
+void initiate_keyexchange(struct ssh_connection *connection);
 
 struct packet_handler *
-make_kexinit_handler(int type,
-		     struct make_kexinit *init,
+make_kexinit_handler(struct make_kexinit *init,
 		     struct lsh_object *extra,
 		     struct alist *algorithms);
 
@@ -184,16 +156,9 @@ struct install_keys *
 make_install_new_keys(int is_server,
 		      struct object_list *algorithms);
 
-#if 0
-struct hash_instance *
-kex_build_secret(struct hash_algorithm *H,
-		 struct lsh_string *exchange_hash,
-		 mpz_t K);
-#endif
-
 void
 keyexchange_finish(struct ssh_connection *connection,
-		   struct install_keys *install,
+		   struct object_list *algorithms,
 		   struct hash_algorithm *H,
 		   struct lsh_string *exchange_hash,
 		   struct lsh_string *K);
