@@ -1,6 +1,6 @@
 /* lsh.h
  *
- * $Id: lsh.h,v 1.14 2000/04/02 19:33:26 nisse Exp $ */
+ * $Id: lsh.h,v 1.16 2000/04/21 21:21:17 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -98,6 +98,9 @@ struct lsh_string
   UINT8 data[1];
 };
 
+/* Strings passed to C library functions must be properly
+ * NUL-terminated. */
+#define NUL_TERMINATED(s) (!(s)->data[(s)->length])
 
 /* Forward declarations of various structures */
 
@@ -118,6 +121,10 @@ struct object_list;
 /* randomness.h */
 struct randomness;
 
+/* reaper.h */
+struct exit_callback;
+struct reap;
+
 /* sexp.h */
 struct sexp;
 struct sexp_iterator;
