@@ -1,6 +1,6 @@
-/* server_pty.h
+/* server_pty.c
  *
- * $Id: server_pty.c,v 1.15 2000/04/19 00:46:40 nisse Exp $
+ * $Id: server_pty.c,v 1.16 2000/06/27 11:36:42 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -163,7 +163,7 @@ pty_grantpt_uid(int master, uid_t user)
       
     }
 }
-#endif HAVE_UNIX98_PTYS
+#endif /* HAVE_UNIX98_PTYS */
 
 int pty_allocate(struct pty_info *pty,
 		 uid_t user
