@@ -1,6 +1,6 @@
 /* server_session.c
  *
- * $Id: server_session.c,v 1.44 2000/06/01 17:48:04 nisse Exp $
+ * $Id: server_session.c,v 1.47 2000/06/27 20:47:47 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -830,11 +830,20 @@ do_spawn_exec(struct channel_request *c,
     case 0:
       { /* Child */
 #define MAX_ENV 1
-	/* No args, end the USER_EXEC method fills in argv[0]. */
-	char *argv[] = { NULL, "-c", command_line->data, NULL };
-	
 	struct env_value env[MAX_ENV];
 	int env_length = 0;
+
+	/* No args, and the USER_EXEC method fills in argv[0]. */
+#if 0
+	/* NOTE: HPUX compiler can't handle array initialization. */
+	char *argv[] = { NULL, "-c", command_line->data, NULL };
+#else
+	char *argv[4];
+	argv[0] = NULL;
+	argv[1] = "-c";
+	argv[2] = command_line->data;
+	argv[3] = NULL;
+#endif
 	
 	debug("do_spawn_shell: Child process\n");
 	assert(getuid() == connection->user->uid);
