@@ -2,7 +2,7 @@
  *
  * Create an SRP verifier
  *
- * $Id: srp-gen.c,v 1.1 2000/05/28 15:04:09 nisse Exp $ */
+ * $Id: srp-gen.c,v 1.3 2000/06/01 18:06:32 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -88,12 +88,12 @@ make_srp_gen_options(struct io_backend *backend,
   self->backend = backend;
   self->e = e;
 
-  self->G = make_ssh_group1();
+  self->G = make_ssh_ring_srp_1();
   self->H = &sha1_algorithm;
   self->file = NULL;
   self->dest = NULL;
 
-  self->style = SEXP_TRANSPORT;
+  self->style = -1;
 
   self->name = getenv("LOGNAME");
   self->passwd = NULL;
@@ -138,6 +138,9 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
       break;
 
     case ARGP_KEY_END:
+      if (!self->name)
+	argp_error(state, "No user name given. Use the -l option, or set LOGNAME in the environment.");
+
       {
 	struct lsh_fd *fd;
 	
@@ -157,10 +160,7 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
 	  }
 	self->dest = &fd->write_buffer->super;
       }
-	  
-      if (!self->name)
-	argp_error(state, "No user name given. Use the -l option, or set LOGNAME in the environment.");
-	  
+      
       while (!self->passwd)
 	{
 	  struct lsh_string *pw;
@@ -181,6 +181,9 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
 
 	  lsh_string_free(again);
 	}
+      if (self->style < 0)
+	self->style = self->file ? SEXP_CANONICAL : SEXP_TRANSPORT;
+      
       break;
 
     case 'o':
@@ -243,7 +246,7 @@ int main(int argc, char **argv)
   argp_parse(&main_argp, argc, argv, 0, NULL, options);
 
   A_WRITE(options->dest,
-	  SEXP_FORMAT(srp_gen(options), options->style, 0));
+	  sexp_format(srp_gen(options), options->style, 0));
 
   io_run(backend);
 
