@@ -1,6 +1,6 @@
 /* tcpforward.h
  *
- * $Id: tcpforward.h,v 1.13 2000/03/26 21:37:56 nisse Exp $
+ * $Id: tcpforward.h,v 1.14 2000/04/21 22:29:46 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -84,10 +84,6 @@ extern struct channel_open channel_open_forwarded_tcpip;
 
 struct global_request *make_tcpip_forward_request(struct command *callback);
 
-#if 0
-struct global_request *make_cancel_tcpip_forward_request(void);
-#endif
-
 extern struct global_request tcpip_cancel_forward;
 
 #endif /* LSH_TCPFORWARD_H_INCLUDED */
